Class: Fastlane::Helper::GoogleAnalyticsHelper
- Inherits:
-
Object
- Object
- Fastlane::Helper::GoogleAnalyticsHelper
- Defined in:
- lib/fastlane/plugin/google_analytics/helper/google_analytics_helper.rb
Class Method Summary collapse
-
.show_message ⇒ Object
class methods that you define here become available in your action as
Helper::GoogleAnalyticsHelper.your_method.
Class Method Details
.show_message ⇒ Object
class methods that you define here become available in your action as Helper::GoogleAnalyticsHelper.your_method
7 8 9 |
# File 'lib/fastlane/plugin/google_analytics/helper/google_analytics_helper.rb', line 7 def self. UI.("Hello from the google_analytics plugin helper!") end |